--
-- TatraTrailer
-- Scripts for Tatra trailers
--
-- @author  Tomas Kralicek (RabbiT_CZ)
-- @date  16/09/09
--
-- t.kralicek@gmail.com
--

TatraTrailer815 = {};

function TatraTrailer815.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Attachable, specializations);
end;

function TatraTrailer815:load(xmlFile)
    
    -- Brake lights initializaiton
    self.brakelight = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.brake#index"));
    
    -- Turn lights
    self.leftTurnObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.leftTurn#index"))
    setVisibility(self.leftTurnObject, false);
    self.leftTurnActive = false;
    self.flashLeft = false;
    
    self.rightTurnObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.rightTurn#index"))
    setVisibility(self.rightTurnObject, false);
    self.rightTurnActive = false;
    self.flashRight = false;
    
    self.flash = false;
    self.flashWarn = false;
    self.timer = 10;
    
    -- Back lights
    self.numLights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.lights#count"), 0);
    self.lightObjects = {};
    for i=1, self.numLights do
        local lightnamei = string.format("vehicle.lights.light" .. "%d", i);
        self.lightObjects[i] = Utils.indexToObject(self.rootNode, getXMLInt(xmlFile, lightnamei .. "#index"));
        setVisibility(self.lightObjects[i], false);
    end;
    self.lightsActive = false;
    
    self.attacherName = "";
end;

function TatraTrailer815:delete()
end;

function TatraTrailer815:mouseEvent(posX, posY, isDown, isUp, button)
end;

function TatraTrailer815:keyEvent(unicode, sym, modifier, isDown)
    if InputBinding.isPressed(InputBinding.LEFTTURN) then
        if not self.flashLeft or self.flashWarn then
            self.flashLeft = false;
        end;
        self.flashLeft = not self.flashLeft;
        self.flashRight = false;
        self.flashWarn = false;
        self.timer = 10;
    end;
    if InputBinding.isPressed(InputBinding.RIGHTTURN) then
        if not self.flashRight or self.flashWarn then
            self.flashRight = false;
        end;
        self.flashRight = not self.flashRight;
        self.flashLeft = false;
        self.flashWarn = false;
        self.timer = 10;
    end;
    if InputBinding.isPressed(InputBinding.WARNLIGHTS) then
        if self.flashWarn then
            self.flashLeft = false;
            self.flashRight = false;
        else
            self.rightTurnActive = false;
            self.leftTurnActive = false;
            self.flashLeft = true;
            self.flashRight = true;
        end;
        self.flashWarn = not self.flashWarn;
        self.timer = 10;
    end;
    
    if InputBinding.isPressed(InputBinding.TOGGLE_LIGHTS) then
        if self.attacherName == "TatraAgro" then
            self.lightsActive = self.attacherVehicle.lightsActive
        else
            if not self.lightsActive then
                self.lightsActive = true;
            else
    			self.lightsActive = false;
    		end;
		end;
    end;
end;

function TatraTrailer815:update(dt)

		if Input.isKeyPressed(Input.KEY_s) then
				setVisibility(self.brakelight, true);
			end;

			if not Input.isKeyPressed(Input.KEY_s) then
				setVisibility(self.brakelight, false);
			end;


    -- Back lights
    for i=1, self.numLights do
        setVisibility(self.lightObjects[i], self.lightsActive);
	end;
    
	-- Turn lights
    if self.flashLeft or self.flashRight then
        self.timer = self.timer - dt;
        if self.flashRight or self.flashWarn then
            if self.timer < 0 then
                self.rightTurnActive = not self.rightTurnActive;
            end;
        else
            self.rightTurnActive = false;
        end;
    
        if self.flashLeft or self.flashWarn then
            if self.timer < 0 then
                self.leftTurnActive = not self.leftTurnActive;
            end;
        else
            self.leftTurnActive = false;
        end;
        if self.timer < 0 then
            self.timer = 500;
        end;
    else
        self.rightTurnActive = false;
        self.leftTurnActive = false;
    end;
    setVisibility(self.rightTurnObject, self.rightTurnActive);
    setVisibility(self.leftTurnObject, self.leftTurnActive);
end;

function TatraTrailer815:onDetach()
    self.lightsActive = false;
    self.attacherVehicle = nil;
    Trailer:onDetach(self);
end;

function TatraTrailer815:onAttach(attacherVehicle)
    self.attacherVehicle = attacherVehicle;
    if self.attacherVehicle ~= nil then
        self.attacherName = getName(attacherVehicle.components[1].node);
        print(self.attacherName);
    end;
end;

function TatraTrailer815:draw()

end;

